@@ -21,6 +21,10 @@
 #  include "DMD_helper.h"
 #endif
 
+#if !HAVE_PERL_VERSION(5, 16, 0)
+#  define XS_INTERNAL(name)  static XS(name)
+#endif
+
 /* There's no reason these have to match those in Future.pm but for now we
  * might as well just copy the same values
  */
@@ -848,7 +852,7 @@ static void S_cancel_pending_subs(pTHX_ struct FutureXS *self)
   }
 }
 
-static XS(sub_on_ready_waitall)
+XS_INTERNAL(sub_on_ready_waitall)
 {
   dXSARGS;
 
@@ -902,7 +906,7 @@ SV *Future_new_waitallv(pTHX_ SV **subs, size_t n)
   return f;
 }
 
-static XS(sub_on_ready_waitany)
+XS_INTERNAL(sub_on_ready_waitany)
 {
   dXSARGS;
   SV *thissub = ST(0);
@@ -993,7 +997,7 @@ static void S_compose_needsall_result(pTHX_ struct FutureXS *self)
   }
 }
 
-static XS(sub_on_ready_needsall)
+XS_INTERNAL(sub_on_ready_needsall)
 {
   dXSARGS;
   SV *thissub = ST(0);
@@ -1076,7 +1080,7 @@ SV *Future_new_needsallv(pTHX_ SV **subs, size_t n)
   return f;
 }
 
-static XS(sub_on_ready_needsany)
+XS_INTERNAL(sub_on_ready_needsany)
 {
   dXSARGS;
   SV *thissub = ST(0);
